# archinfo
[![Latest Release](https://img.shields.io/pypi/v/archinfo.svg)](https://pypi.python.org/pypi/archinfo/)
[![Python Version](https://img.shields.io/pypi/pyversions/archinfo)](https://pypi.python.org/pypi/archinfo/)
[![PyPI Statistics](https://img.shields.io/pypi/dm/archinfo.svg)](https://pypistats.org/packages/archinfo)
[![License](https://img.shields.io/github/license/angr/archinfo.svg)](https://github.com/angr/archinfo/blob/master/LICENSE)

archinfo is a collection of classes that contain architecture-specific information.
It is useful for cross-architecture tools (such as pyvex).

## Project links
Project repository: https://github.com/angr/archinfo

Documentation: https://api.angr.io/projects/archinfo/en/latest/
